Module: FeCoreExt::CoreExt::String
- Included in:
- String
- Defined in:
- lib/fe_core_ext/core_ext/string.rb
Instance Method Summary collapse
- #alphanumeric_zen_to_han ⇒ Object
- #eucjp_encodable ⇒ Object
- #integer? ⇒ Boolean
- #kana_upcase ⇒ Object
- #match?(str) ⇒ Boolean
- #not_number? ⇒ Boolean
- #sjis_encodable ⇒ Object
-
#strong_strip ⇒ Object
remove also no break space and other space like characters.
- #to_date_in_ja ⇒ Object
- #to_date_in_ja_heisei ⇒ Object
- #to_date_in_ja_seireki ⇒ Object
- #to_decimal ⇒ Object
- #to_decimal_new ⇒ Object
- #to_float ⇒ Object
- #to_han_kana ⇒ Object
- #to_integer ⇒ Object
- #to_katakana ⇒ Object
- #to_pathname ⇒ Object
- #to_zen_kana ⇒ Object
- #valid_number? ⇒ Boolean
-
#zen_to_han ⇒ Object
deprecated.
Instance Method Details
#alphanumeric_zen_to_han ⇒ Object
51 52 53 |
# File 'lib/fe_core_ext/core_ext/string.rb', line 51 def alphanumeric_zen_to_han tr('0-9A-Za-z &・-()', '0-9A-Za-z &・\-()') end |
#eucjp_encodable ⇒ Object
99 100 101 102 |
# File 'lib/fe_core_ext/core_ext/string.rb', line 99 def eucjp_encodable tr("\uFF5E\uFF0D\uFFE0\uFFE1\uFFE2\u2015\u2225", "\u301C\u2212\u00A2\u00A3\u00AC\u2014\u2016") end |
#integer? ⇒ Boolean
15 16 17 |
# File 'lib/fe_core_ext/core_ext/string.rb', line 15 def integer? self.to_integer.to_s == self.delete(',') end |
#kana_upcase ⇒ Object
63 64 65 |
# File 'lib/fe_core_ext/core_ext/string.rb', line 63 def kana_upcase tr('ァィゥェォヵヶッャュョヮ', 'アイウエオカケツヤユヨワ') end |
#match?(str) ⇒ Boolean
59 60 61 |
# File 'lib/fe_core_ext/core_ext/string.rb', line 59 def match?(str) /#{str}/ === self end |
#not_number? ⇒ Boolean
38 39 40 |
# File 'lib/fe_core_ext/core_ext/string.rb', line 38 def not_number? to_i == 0 && match('0').nil? end |
#sjis_encodable ⇒ Object
94 95 96 97 |
# File 'lib/fe_core_ext/core_ext/string.rb', line 94 def sjis_encodable tr("\u301C\u2212\u00A2\u00A3\u00AC\u2014\u2016", "\uFF5E\uFF0D\uFFE0\uFFE1\uFFE2\u2015\u2225") end |
#strong_strip ⇒ Object
remove also no break space and other space like characters.
90 91 92 |
# File 'lib/fe_core_ext/core_ext/string.rb', line 90 def strong_strip reverse.gsub(/^\p{Zs}+|^\p{Cf}+/, '').reverse.gsub(/^\p{Zs}+|^\p{Cf}+/, '') end |
#to_date_in_ja ⇒ Object
77 78 79 |
# File 'lib/fe_core_ext/core_ext/string.rb', line 77 def to_date_in_ja to_date_in_ja_seireki || to_date_in_ja_heisei end |
#to_date_in_ja_heisei ⇒ Object
85 86 87 |
# File 'lib/fe_core_ext/core_ext/string.rb', line 85 def to_date_in_ja_heisei match(/平成(\d{2})年(\d{1,2})月(\d{1,2})日/) {Date.new($1.to_i + 1988, $2.to_i, $3.to_i)} end |
#to_date_in_ja_seireki ⇒ Object
81 82 83 |
# File 'lib/fe_core_ext/core_ext/string.rb', line 81 def to_date_in_ja_seireki match(/(\d{4})年(\d{1,2})月(\d{1,2})日/) {Date.new($1.to_i, $2.to_i, $3.to_i)} end |
#to_decimal ⇒ Object
19 20 21 22 |
# File 'lib/fe_core_ext/core_ext/string.rb', line 19 def to_decimal return if not_number? delete(',').to_d end |
#to_decimal_new ⇒ Object
24 25 26 27 |
# File 'lib/fe_core_ext/core_ext/string.rb', line 24 def to_decimal_new return unless valid_number? delete(',').to_d end |
#to_float ⇒ Object
29 30 31 32 |
# File 'lib/fe_core_ext/core_ext/string.rb', line 29 def to_float return unless valid_number? delete(',').to_f end |
#to_han_kana ⇒ Object
67 68 69 70 |
# File 'lib/fe_core_ext/core_ext/string.rb', line 67 def to_han_kana return if self.nil? NKF.nkf('-wxZ4', self) end |
#to_integer ⇒ Object
10 11 12 13 |
# File 'lib/fe_core_ext/core_ext/string.rb', line 10 def to_integer return unless valid_number? delete(',').to_i end |
#to_katakana ⇒ Object
55 56 57 |
# File 'lib/fe_core_ext/core_ext/string.rb', line 55 def to_katakana tr('ぁ-ん', 'ァ-ン') end |
#to_pathname ⇒ Object
34 35 36 |
# File 'lib/fe_core_ext/core_ext/string.rb', line 34 def to_pathname Pathname(self) end |
#to_zen_kana ⇒ Object
72 73 74 75 |
# File 'lib/fe_core_ext/core_ext/string.rb', line 72 def to_zen_kana return if self.nil? NKF.nkf('-wX', self) end |
#valid_number? ⇒ Boolean
42 43 44 |
# File 'lib/fe_core_ext/core_ext/string.rb', line 42 def valid_number? match?(/^-?([0-9][\d\,\.]*)$/) end |
#zen_to_han ⇒ Object
deprecated
47 48 49 |
# File 'lib/fe_core_ext/core_ext/string.rb', line 47 def zen_to_han tr('0-9A-Za-z &・-()', '0-9A-Za-z &・\-()') end |